==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/app/controllers/spirit_hub/settings_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class SettingsController < ApplicationController
    before_action :find_models
    before_action :set_model

    def index
      authorize(Setting, policy_class: SettingPolicy)

      respond_to(&:html)
    end

    def inline_edit
      authorize @model

      key = params[:key].to_sym

      render turbo_stream: turbo_stream.update(
        "inline_edit_#{key}_#{@model.id}",
        partial: 'inline_edit',
        locals: { model: @model, key: }
      )
    end

    def update_inline
      authorize @model

      key         = inline_update_params[:key].to_sym
      @model[key] = inline_update_params[key]

      if @model.save
        Setting.clear_cache!
        flash.now[:notice] = 'Paramètre mis à jour'
        update_flash_message
        if key == :object_name
          flash[:notice] = 'Nom de l\'objet à traiter mis à jour'
          return redirect_to(action: :index)
        end

        render turbo_stream: [
          turbo_stream.update(
            "inline_value_#{key}_#{@model.id}",
            partial: 'spirit_hub/common/inline_value',
            locals: { model: @model, key:, value: @model[key] }
          ),
          @turbo_actions
        ].flatten.compact
      else
        render turbo_stream: turbo_stream.update(
          "inline_edit_#{key}_#{@model.id}",
          partial: 'inline_edit',
          locals: { model: @model, key: }
        )
      end
    end

    private

    def inline_update_params
      params.require(:spirit_hub_setting).permit(:key, :color_mode, :theme, :object_name)
    end

    def find_models
      @models = policy_scope(Setting, policy_scope_class: SettingPolicy::Scope)
    end

    def set_model
      @model = Setting.new
    end
  end
end

==> spirit_hub-1.0.0.15.tar.gz: spirit_hub-1.0.0.15/app/controllers/spirit_hub/settings_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class SettingsController < ApplicationController
    before_action :find_models
    before_action :set_model

    def index
      authorize(Setting, policy_class: SettingPolicy)

      respond_to(&:html)
    end

    def inline_edit
      authorize @model

      key = params[:key].to_sym

      render turbo_stream: turbo_stream.update(
        "inline_edit_#{key}_#{@model.id}",
        partial: 'inline_edit',
        locals: { model: @model, key: }
      )
    end

    def update_inline
      authorize @model

      key         = inline_update_params[:key].to_sym
      @model[key] = inline_update_params[key]

      if @model.save
        Setting.clear_cache!
        flash.now[:notice] = 'Paramètre mis à jour'
        update_flash_message
        if key == :object_name
          flash[:notice] = 'Nom de l\'objet à traiter mis à jour'
          return redirect_to(action: :index)
        end

        render turbo_stream: [
          turbo_stream.update(
            "inline_value_#{key}_#{@model.id}",
            partial: 'spirit_hub/common/inline_value',
            locals: { model: @model, key:, value: @model[key] }
          ),
          @turbo_actions
        ].flatten.compact
      else
        render turbo_stream: turbo_stream.update(
          "inline_edit_#{key}_#{@model.id}",
          partial: 'inline_edit',
          locals: { model: @model, key: }
        )
      end
    end

    private

    def inline_update_params
      params.require(:spirit_hub_setting).permit(:key, :color_mode, :theme, :object_name, :organism_type)
    end

    def find_models
      @models = policy_scope(Setting, policy_scope_class: SettingPolicy::Scope)
    end

    def set_model
      @model = Setting.new
    end
  end
end
